"""

It's a set of Python modules designed for OS(No,it's not)
programs in the python language. The package can't portable,
just can run with Windows

les's say that!       'Noodows!'

"""
